### Name: llamodified
### Title: Apply a Function (after modifying argument) over a List or List
###   of lists
### Aliases: lamodified llamodified amList-class amLlist-class
###   coef,amList-method show,amList-method summary,amList-method
###   coef,amLlist-method show,amLlist-method summary,amLlist-method
### Keywords: package

### ** Examples


## Not run: 

library(richards)
library(nlme)

data(simulatedPlates)

groupedData <- groupedData(SIGNAL ~ CONC | PT / LAY / PLA, 
                           inner = ~ PR, data = simulatedPlates)

fullData <- split(groupedData, list(groupedData[,"PT"],
                                    groupedData[,"LAY"],
                                    groupedData[,"PLA"]),
                  drop = TRUE)

n <- length(fullData)
listData <- fullData[1:28]

fit.Richards.BP <- function(X, start, lower, upper)
 {
  try(nls(SIGNAL ~ SSrichards(CONC, a, d, b, x50, ny),
          lower = lower, upper = upper, algorithm = "port",
          control = nls.control(maxiter = 1000, tol = 1e-04, 
                                warnOnly = TRUE), data = X))
 }

fit.Gompertz.BP <- function(X, start, lower, upper)
 {
  try(nls(SIGNAL ~ SSny0(CONC, a, d, b, x50),
          lower = lower, upper = upper, algorithm = "port",
          control = nls.control(warnOnly = TRUE), data = X))
 }

fit.GompertzLog.D <- function(X, start, lower, upper)
 {
  try(nls(SIGNAL ~ SSny0Log(log(CONC), a, d, xmid, scal),
          control = nls.control(warnOnly = TRUE), data = X))
 }

fit.GompertzLogB.D <- function(X, start, lower, upper)
 {
  try(nls(SIGNAL ~ SSny0LogB(log(CONC), a, d, xmid, b),
          control = nls.control(warnOnly = TRUE), data = X))
 }

fit.Fpl.BP <- function(X, start, lower, upper)
 {
  try(nls(SIGNAL ~ SSny1(CONC, a, d, b, x50),
          lower = lower, upper = upper, algorithm = "port",
          control = nls.control(maxiter = 1000, tol = 1e-04, 
                                warnOnly = TRUE), data = X))
 }

fit.Fpl.D <- function(X, start, lower, upper)
 {
  try(nls(SIGNAL ~ SSny1(CONC, a, d, b, x50),
          control = nls.control(warnOnly = TRUE), data = X))
 }

Start <- list(a =  0.0, d =  3.0,  b = 1.0, x50 = 0.10,  ny =   0.1)
Lower <- list(a = -0.5, d =  0.02, b = 0.1, x50 = 0.001, ny =  -5)
Upper <- list(a =  0.5, d = 15.0,  b = 2.5, x50 = 5.00,  ny = 128)

myApplyFUN2X <- 
  function(X, FUN, start = Start, lower = Lower, upper = Upper,
              Report = print, ...) {
    if (dim(X)[1] > 0) {
      result <- FUN(X, start, lower, upper)
      if (is.null(result) | class(result) == "try-error")
        Report(X)
      return(result)
    }
  }

fits.Richards.BP    <- lamodified(listData, FUN = fit.Richards.BP,
                                  applyFUN2X = myApplyFUN2X, n = 5)
coef(fits.Richards.BP)

fits.Gompertz.BP    <- lamodified(listData, FUN = fit.Gompertz.BP,
                                  applyFUN2X = myApplyFUN2X, n = 4)
coef(fits.Gompertz.BP)

fits.GompertzLog.D <- lamodified(listData, FUN = fit.GompertzLog.D,
                                 applyFUN2X = myApplyFUN2X, n = 4)
coef(fits.GompertzLog.D)

fits.GompertzLogB.D <- lamodified(listData, FUN = fit.GompertzLogB.D,
                                  applyFUN2X = myApplyFUN2X, n = 4)
coef(fits.GompertzLogB.D)

fits.Fpl.BP         <- lamodified(listData, FUN = fit.Fpl.BP,
                                  applyFUN2X = myApplyFUN2X, n = 4)
coef(fits.Fpl.BP)

fits.Fpl.D          <- lamodified(listData, FUN = fit.Fpl.D,
                                  applyFUN2X = myApplyFUN2X, n = 4)
coef(fits.Fpl.D)

X <- cbind(coef(fits.Richards.BP), coef(fits.Fpl.BP))

## End(Not run)




